# Discrete Constraints

## Material Connectivity
::: fdtdx.constraints.discrete.RemoveFloatingMaterial
::: fdtdx.constraints.discrete.ConnectHolesAndStructures

## Feature Size Control
::: fdtdx.constraints.discrete.circular_brush
::: fdtdx.constraints.discrete.BrushConstraint2D

## Smoothing and Filtering
::: fdtdx.constraints.discrete.BinaryMedianFilterModule
::: fdtdx.constraints.discrete.BOTTOM_Z_PADDING_CONFIG
::: fdtdx.constraints.discrete.BOTTOM_Z_PADDING_CONFIG_REPEAT

## Pillar Constraints
::: fdtdx.constraints.pillars.PillarMapping
